# meds/bots/cli.py
#
#

""" Console Interface. """

__copyright__ = "Copyright 2015, B.H.J Thate"

## IMPORTS

from meds.defines import GREEN, ENDC
from meds.utils.parse import txt_parse
from meds.main import fleet
from meds.object import Object
from meds.bots import Bot
from meds.cfg import cfg

import time
import sys

## CLI

class CLI(Bot):

    """ Console Line Interface Bot. """

    cc = "none"
    default = ""

    def raw(self, *args, **kwargs):
        """
            raw(txt)

            Output to sys.stdout.

            >>> bot = CLI()
            >>> bot.raw("bla")
            bla

        """
        sys.stdout.write(str(args[0]))
        sys.stdout.write("\n")

    def say(self, *args, **kwargs):
        """
            say(txt)

            Say something on a channel.

            >>> bot = CLI()
            >>> bot.say("mekker", "bla")
            bla

        """
        self.raw(args[1])

    def prompt(self, *args, **kwargs):
        """
            prompt()

            Wait for user input.

            >>> bot = CLI()
            >>> bot.prompt(1.0) # doctest: +ELLIPSIS
            '...'

        """
        self.wait(*args, **kwargs)
        if cfg.main.colors: return "%s %s<%s " % (time.ctime(time.time()).split()[-2], GREEN, ENDC)
        else: return "%s < " % (time.ctime(time.time()).split()[-2])

    def event(self, *args, **kwargs):
        """
            event()

            Wait for an CLI event..

            >>> bot = CLI()
            >>> e = bot.event("bla")

        """
        event = Object()
        event._target = self
        event.origin = "root@shell"
        self.ready()
        if args: event.txt = args[0]
        else: event.txt = input(self.prompt())
        return event

    def start(self, *args, **kwargs):
        """
            start()

            Start the bot dispatch loop.

            >>> bot = CLI()
            >>> bot.start(single=True)

        """
        fleet.append(self)
        if not cfg.main.shell or "single" in kwargs:
            thrs = self.single(" ".join(cfg.main.runargs))
            if thrs: self.collect(thrs)
            self.ready()
            return
        Bot.start(self, *args, **kwargs)
 